@@ -51,15 +51,16 @@ class TestHoe < MiniTest::Unit::TestCase
     assert_match(/^Hoe.*Rakefiles$/, spec.summary)
     assert_equal files.grep(/^test/), spec.test_files
 
-    deps = spec.dependencies
+    deps = spec.dependencies.sort_by { |dep| dep.name }
 
-    assert_equal 1, deps.size
+    expected = [["hoe",       :development, ">= #{Hoe::VERSION}"]]
 
-    dep = deps.first
+    expected << ["rubyforge", :development, ">= #{::RubyForge::VERSION}"] if
+      defined? ::RubyForge
 
-    assert_equal 'hoe', dep.name
-    assert_equal :development, dep.type
-    assert_equal ">= #{Hoe::VERSION}", dep.version_requirements.to_s
+    assert_equal expected, deps.map { |dep|
+      [dep.name, dep.type, dep.requirement.to_s]
+    }
   end
 
   def test_plugins
@@ -69,7 +70,6 @@ class TestHoe < MiniTest::Unit::TestCase
     Hoe.plugin :first, :second
     assert_equal before + [:first, :second], Hoe.plugins
   ensure
-    # FIX: maybe add Hoe.reset
     Hoe.plugins.replace before
   end
 
